'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

function __spreadArrays() {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
}

var createShadowDOM = function (currentChild, setShadowItemFn) {
    var children = currentChild.props.children;
    if (Array.isArray(children)) {
        React__default.Children.forEach(children, function (child) {
            if (typeof child === "object")
                createShadowDOM(child, setShadowItemFn);
            else if (child.toString().trim().length) {
                setNewChild();
            }
        });
    }
    else if (typeof children === "object") {
        createShadowDOM(children, setShadowItemFn);
    }
    else if (children.toString().trim().length) {
        setNewChild();
    }
    function setNewChild() {
        setShadowItemFn(function (child) {
            if (child)
                return __spreadArrays(child, [currentChild]);
            return [currentChild];
        });
    }
};

var defaults = {
    TIME_TO_HIGHLIGHT: 500,
    TIME_TO_STOP_HIGHLIGHT: 2000,
    HIGHLIGHT_CLASS: "rc-highlight"
};

var setHighlight = function (child, id, isInitial, showAfter, hideAfter, highlightStyle, clearHighlightRef, setClearHighlightFn, updateClearHandler) {
    if (!isInitial && child.ref.current) {
        var element_1 = child.ref.current;
        if (clearHighlightRef) {
            clearTimeout(clearHighlightRef);
        }
        setTimeout(function () {
            element_1.className += " " + highlightStyle;
        }, showAfter);
        var clearHighlight = setTimeout(function () {
            element_1.className = element_1.className.substr(0, element_1.className.indexOf(highlightStyle) - 1);
        }, showAfter + hideAfter);
        setClearHighlightFn(clearHighlight);
        updateClearHandler(id, clearHighlight);
    }
};

var ShadowChild = function (_a) {
    var child = _a.child, id = _a.id, showAfter = _a.showAfter, hideAfter = _a.hideAfter, highlightStyle = _a.highlightStyle, clearHandler = _a.clearHandler, updateClearHandler = _a.updateClearHandler;
    var initialMount = React.useRef(true);
    var _b = React.useState(clearHandler), clearHighlightRef = _b[0], setClearHighlightRef = _b[1];
    var changedChildren = Array.isArray(child.props.children)
        ? child.props.children.find(function (c) { return c.toString().trim().length; })
        : child.props.children;
    React.useEffect(function () {
        if (initialMount.current) {
            initialMount.current = false;
            return;
        }
        setHighlight(child, id, initialMount.current, showAfter, hideAfter, highlightStyle, clearHighlightRef, setClearHighlightRef, updateClearHandler);
    }, [changedChildren]);
    return React__default.createElement(React__default.Fragment, null);
};

var addStyleString = function (str, isSSR) {
    if (isSSR === void 0) { isSSR = false; }
    // do nothing in case of SSR
    if (!document || isSSR) {
        console.warn("\"react-change-highlight\", As you're using server-side rendering, it's a must to create and pass your css class to the highlightStyle attribute for \"ChangeHighlight\" component.");
        return;
    }
    var node = document.createElement("style");
    node.innerHTML = str;
    document.body.appendChild(node);
};

var listOfClearHighlightFunctions = [];
var updateClearHandler = function (childId, Fn) {
    listOfClearHighlightFunctions[childId] = Fn;
};
var ChangeHighlight = function (_a) {
    var children = _a.children, containerClassName = _a.containerClassName, _b = _a.showAfter, showAfter = _b === void 0 ? defaults.TIME_TO_HIGHLIGHT : _b, _c = _a.hideAfter, hideAfter = _c === void 0 ? defaults.TIME_TO_STOP_HIGHLIGHT : _c, _d = _a.highlightStyle, highlightStyle = _d === void 0 ? defaults.HIGHLIGHT_CLASS : _d, _e = _a.disabled, disabled = _e === void 0 ? false : _e, _f = _a.ssr, ssr = _f === void 0 ? false : _f;
    var _g = React.useState([]), shadowDOM = _g[0], setShadowDOM = _g[1];
    var isInitialMount = React.useRef(true);
    React.useEffect(function () {
        if (!disabled) {
            if (isInitialMount.current) {
                if (!!highlightStyle) {
                    addStyleString("\n          ." + defaults.HIGHLIGHT_CLASS + " {\n            background: #f8ffb4 !important;\n            transition: 0.25s ease-in-out;\n          }\n        ", ssr);
                }
                isInitialMount.current = false;
            }
            setShadowDOM([]);
            createShadowDOM({ props: { children: children } }, setShadowDOM);
        }
    }, [children]);
    return (React__default.createElement("div", { className: containerClassName },
        shadowDOM.map(function (child, index) { return (React__default.createElement(ShadowChild, { key: index, id: index, child: child, showAfter: showAfter, hideAfter: hideAfter, highlightStyle: highlightStyle, clearHandler: listOfClearHighlightFunctions[index], updateClearHandler: updateClearHandler })); }),
        children));
};

module.exports = ChangeHighlight;
